-- *************************************************
-- Mentett adatok kezelse
-- *************************************************
TPluginData = class(Turbine.Object);
opGearWindow = Turbine.UI.Lotro.Window();
opGearPanel = Turbine.UI.Control();
opLabelMWGearName = TLabel(opGearWindow, "Select a gear:", 20, 35, 100, 20);
opEditWMGearName = TEdit(opGearWindow, 120, 35, 140, 20);
opSelectGearBtn = TImageButton(opGearWindow, 260,35,20,20, pluginRoot .. "resource/gearselectbtn.tga", pluginRoot .. "resource/gearselectbtn.tga", pluginRoot .. "resource/gearselectbtn.tga");
oplabelSave = TLabel(opGearPanel, 'Gear name:', 20, 90, 100, 20);
opEditSave = TEdit(opGearPanel, 130, 90, 200, 20);
opBtnSave = TButton(opGearPanel, 'Save', 340, 90, 100, 20);	
opBtnClone = TButton(opGearPanel, 'Add as new', 450, 90, 100, 20);
opBtnDelete = TButton(opGearPanel, 'Delete', 560, 90, 100, 20);
opBtnCancel = TButton(opGearPanel, 'Cancel', 670, 90, 100, 20);
opGearMenu = Turbine.UI.ContextMenu();
opGearMenuItems = opGearMenu:GetItems();
opBtnClose = TButton(opGearWindow, 'Close', 365, 220, 100, 20);


-- Kontruktor
-- ===================================
function TPluginData:Constructor()
	Turbine.Object.Constructor( self );
	self.charFileName = "BnyGearUp";
	self.serverFileName = "BnyGearUpS";
	self.gearSets = {};
	self.opWearedItemA = {};
	self.opSlotItemA = {};
	self.visibleIcon = 0;
end

-- PluginData fjl beolvassa
-- ===================================
function TPluginData:LoadState()
	debug("@TPluginData:LoadState()");
	local obj = Turbine.Object();
	pcall(function() obj = PatchDataLoad( Turbine.DataScope.Character, self.charFileName)	end	);
	if obj ~= nil then
		self.gearSets = obj.items;
		self:GearSort();
	end
end

-- Adatok PluginData fjlba rsa
-- ===================================
function TPluginData:SaveState()
	debug("@TPluginData:SaveState()");
	local obj = Turbine.Object();
	self:GearSort();
	obj.items = self.gearSets;
	pcall(function() PatchDataSave( Turbine.DataScope.Character, self.charFileName, obj) end);
end

-- A gear listt ABS sorba rendezi
-- ===================================
function TPluginData:GearSort()
	debug("@TPluginData:GearSort()");
	table.sort(self.gearSets, function (arg1,arg2) if arg1<arg2 then return(true) end end);	
end	-- GearSort

--	Objektumban trolt itemtmb frisstse opcik formrl
-- ===================================
function TPluginData:RefreshItemSet( setName )
	debug("@TPluginData:RefreshItemSet()");	
	if setName == nil then return false; end
	self.gearSets[setName] = {};	
	for f=1, #self.opSlotItemA do
		nev = self.opSlotItemA[f]:GetName();
		if (nev ~= "") then
			self.gearSets[setName][self.opSlotItemA[f].slot] = {
				["slot"]=self.opSlotItemA[f].slot , 
				["id"]=self.opSlotItemA[f]:GetItem(), 
				["name"]=self.opSlotItemA[f]:GetName()
			};
		end;
	end
	self:GearSort();
end

-- Ablak ltrehozsa
-- ===================================
function TPluginData:CreateGearSetupWindow()
	debug("@TPluginData:CreateGearSetupWindow()");		
	opGearWindow:SetSize(830, 250);
	opGearWindow:SetText("Set up a gear");
	opGearWindow:SetLeft((Turbine.UI.Display:GetWidth()-opGearWindow:GetWidth())/2);
	opGearWindow:SetTop((Turbine.UI.Display:GetHeight()-opGearWindow:GetHeight())/2);
	
	opEditWMGearName:SetReadOnly(true);
	opSelectGearBtn.MouseClick = function() opGearMenu:ShowMenu() 	end
	
	opGearPanel:SetParent(opGearWindow);
	opGearPanel:SetPosition(20, 70);
	opGearPanel:SetSize(780, 120);
	opGearPanel:SetBackColor(Turbine.UI.Color(1,0,0,0));
	opGearPanel:SetVisible(false);
	
	oplabelSave:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight);
	opEditSave:SetMultiline(false);	
	-- Ablak bezrs
	opBtnClose.Click = function()
		opGearPanel:SetVisible(false);
		opEditWMGearName:SetText("");
		opGearWindow:Close();
	end
	-- Gear set mentse
	opBtnSave.Click = function()
		debug("@TPluginData:opBtnSave.Click");	
		if string.len(opEditSave:GetText()) ~= 0 then
			if opEditWMGearName:GetText() ~= "- new -" then
				self.gearSets[opEditWMGearName:GetText()] = nil;
			end			
			self:RefreshItemSet(opEditSave:GetText());
			self:SaveState();		
			self:BuildGearList();
			GearMenuRefresh();
			if (optionsO.activeItemSetName == opEditWMGearName:GetText()) then
				debug("Aktiv set lett modositva");
				optionsO.activeItemSetName = opEditSave:GetText();
				RepaintMainWindow();
			end
			opGearPanel:SetVisible(false);
			opEditWMGearName:SetText("");
		else
			debug("Try to save without name");
		end	
	end
	-- Gear delete
	opBtnDelete.Click = function()
		if opEditWMGearName:GetText() ~= "- new -" then
			self.gearSets[opEditWMGearName:GetText()] = nil;
			self:GearSort();
			self:SaveState();		
			self:BuildGearList();
			GearMenuRefresh();
			if (optionsO.activeItemSetName == opEditWMGearName:GetText()) then
				debug("Aktiv gear lett torolve.");
				optionsO.activeItemSetName = "";				
				RepaintMainWindow();
			end			
		else
			debug("Try to delete a new gear");
		end			
		opGearPanel:SetVisible(false);
		opEditWMGearName:SetText("");
	end
	-- Gear set save a new collection
	opBtnClone.Click = function()
		if string.len(opEditSave:GetText()) ~= 0 then
			if (self.gearSets[opEditSave:GetText()]) == nil then
				opEditWMGearName:SetText("- new -");
				self:RefreshItemSet(opEditSave:GetText());
				self:SaveState();		
				self:BuildGearList();
				GearMenuRefresh();
				opGearPanel:SetVisible(false);
				opEditWMGearName:SetText("");
			end
		end;
	end	
	-- Gear set Cancel
	opBtnCancel.Click = function()
		opGearPanel:SetVisible(false);
		opEditWMGearName:SetText("");
	end	
	self:BuildGearList();
	opGearWindow:SetVisible(false);
	opGearWindow:Activate();
end	-- CreateGearSetupWindow

-- Gear men
-- ===================================
function TPluginData:BuildGearList()
	debug("@TPluginData:BuildGearList()");
	opGearMenuItems:Clear();
	opGearMenuItems:Add(Turbine.UI.MenuItem("- new -"));	
	for k, v in pairs( self.gearSets ) do
		opGearMenuItems:Add(Turbine.UI.MenuItem(k));
	end
	for i=1, opGearMenuItems:GetCount() do
		opGearMenuItems:Get(i).Click = function(sender, args) 
			opEditWMGearName:SetText(sender:GetText());
			opEditSave:SetText("");
			if (sender:GetText() ~= "- new -") then opEditSave:SetText(sender:GetText()); end
			opGearMenu:Close();
			opGearPanel:SetVisible(true);
			self:RepaintGearSetupWindow();
		end;
	end;	
end	--BuildGearList

-- Ablak frisstse
-- ===================================
function TPluginData:RepaintGearSetupWindow()
	debug("@TPluginData:RepaintGearSetupWindow()");	
	
	self.opWearedItemA = {};
	self.opSlotItemA = {};	
	ikondb = 0;
	opEditGearName = "";
	if opEditWMGearName:GetText() ~= "- new -" then
		opEditGearName = opEditWMGearName:GetText();
		if self.gearSets[opEditGearName] == nil then
			opEditGearName = "";
		end
	end	
	for index, value in pairs(SlotOrder) do
		opLoadItem = "";
		if opEditGearName ~= "" then
			if self.gearSets[opEditGearName][value] ~= nil then
				opLoadItem = self.gearSets[opEditGearName][value]["id"];
			end
		end
		newLeft = (ikondb*41);
		ikondb = ikondb + 1;
		self.opWearedItemA[ikondb] = TWearSlot(opGearPanel, newLeft, 0, value);
		self.opSlotItemA[ikondb] = TItemSlot(opGearPanel, newLeft, 41, value, opLoadItem, false);
	end
end	-- RepaintGearSetupWindow
	
